@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 #--------------------------------------------------------------------------
 
@@ -25,16 +25,17 @@ Searches for book information from the O'Reilly Media's online catalog.
 #--------------------------------------------------------------------------
 
 ###########################################################################
-#Library Modules                                                          #
+# Inheritence
+
+use base qw(WWW::Scraper::ISBN::Driver);
+
 ###########################################################################
+# Modules
 
-use WWW::Scraper::ISBN::Driver;
 use WWW::Mechanize;
-use Template::Extract;
 
 ###########################################################################
-#Constants                                                                #
-###########################################################################
+# Constants
 
 use constant	ORA		=> 'http://www.oreilly.com';
 use constant	SEARCH	=> 'http://search.oreilly.com';
@@ -43,14 +44,7 @@ use constant	QUERY	=> '?submit.x=17&submit.y=8&q=%s';
 #--------------------------------------------------------------------------
 
 ###########################################################################
-#Inheritence		                                                      #
-###########################################################################
-
-@ISA = qw(WWW::Scraper::ISBN::Driver);
-
-###########################################################################
-#Interface Functions                                                      #
-###########################################################################
+# Public Interface
 
 =head1 METHODS
 
@@ -65,7 +59,10 @@ The returned page should be the correct catalog page for that ISBN. If not the
 function returns zero and allows the next driver in the chain to have a go. If
 a valid page is returned, the following fields are returned via the book hash:
 
-  isbn
+  isbn          (now returns isbn13)
+  isbn10        
+  isbn13
+  ean13         (industry name)
   author
   title
   book_link
@@ -73,6 +70,11 @@ a valid page is returned, the following fields are returned via the book hash:
   description
   pubdate
   publisher
+  binding       (if known)
+  pages         (if known)
+  weight        (if known) (in grammes)
+  width         (if known) (in millimetres)
+  height        (if known) (in millimetres)
 
 The book_link and image_link refer back to the O'Reilly US website.
 
@@ -94,35 +96,29 @@ sub search {
 	    unless($mech->success());
 
 	# The Search Results page
-	my $template = <<END;
-<div class="book_text">[% ... %]
-<p class="title">[% ... %]
-<a href="[% book %]"[% ... %]
-END
+    my $content = $mech->content();
+    my ($book) = $content =~ m!<div class="book_text">\s*<p class="title">\s*<a href="([^"]+)"!;
 
-	my $extract = Template::Extract->new;
-    my $data = $extract->extract($template, $mech->content());
-
-	unless(defined $data) {
+	unless(defined $book) {
         print STDERR "\n#url=$url\n";
         print STDERR "\n#content=".$mech->content();
 	    return $self->handler("Could not extract data from the O'Reilly Media search page [".($mech->uri())."].");
     }
 
-	my $book = $data->{book};
 	$mech->get( $book );
     my $html = $mech->content();
-    $data = undef;
+    my $data = {};
 
     for my $name ('book.isbn','ean','target','reference','isbn','graphic','graphic_medium','graphic_large','book_title','author','keywords','description','date') {
         next    unless($html =~ m!<meta name="$name" content="([^"]+)" />!i);
         $data->{$name} = $1;
     }
 
-    $data->{graphic} ||= $data->{$_}    for('graphic_medium','graphic_large');  # alternative graphic fields
-    $data->{isbn} ||= $data->{$_}       for('book.isbn','ean');                 # alternative EAN13 fields
+    ($data->{isbn13},$data->{isbn10}) = $html =~ m!<dt>(?:Print )?ISBN:</dt><dd[^>]+>([\d-]+)</dd>\s*<dt class="isbn-10"> \| ISBN 10:</dt> <dd>([\d-]+)</dd>!;
+    ($data->{pages}) = $html =~ m!<dt>Pages:</dt> <dd[^>]+>\s*(\d+)\s*</dd>!;
 
-    #$data = $extract->extract($template, $mech->content());
+    $data->{graphic} ||= $data->{$_}    for('graphic_medium','graphic_large');  # alternative graphic fields
+    $data->{$_} =~ s!\D+!!g             for('isbn13','isbn10');
 
 	unless(defined $data) {
         print STDERR "\n#url=$url\n";
@@ -131,8 +127,10 @@ END
     }
 
 	my $bk = {
-		'isbn'			=> $data->{isbn},
-		'ean'		    => $data->{ean},
+		'ean13'		    => $data->{ean},
+		'isbn13'		=> $data->{ean},
+		'isbn10'		=> $data->{isbn10},
+		'isbn'			=> $data->{ean},
 		'author'		=> $data->{author},
 		'title'			=> $data->{book_title},
 		'book_link'		=> $mech->uri(),
@@ -140,6 +138,11 @@ END
 		'description'	=> $data->{description},
 		'pubdate'		=> $data->{date},
 		'publisher'		=> q!O'Reilly Media!,
+		'binding'	    => $data->{binding},
+		'pages'		    => $data->{pages},
+		'weight'		=> $data->{weight},
+		'width'		    => $data->{width},
+		'height'		=> $data->{height}
 	};
 	$self->book($bk);
 	$self->found(1);
@@ -170,13 +173,9 @@ L<WWW::Scraper::ISBN::Driver>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2004-2007 Barbie for Miss Barbell Productions
+  Copyright (C) 2004-2010 Barbie for Miss Barbell Productions
 
   This module is free software; you can redistribute it and/or
-  modify it under the same terms as Perl itself.
-
-The full text of the licenses can be found in the F<Artistic> file included
-with this module, or in L<perlartistic> as part of Perl installation, in
-the 5.8.1 release or later.
+  modify it under the Artistic Licence v2.
 
 =cut
